@@ -29,6 +29,7 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 
+Q_GLOBAL_STATIC( Soprano::Redland::World, s_theWorld )
 
 static QString redlandLogFacilityToString( int facility )
 {
@@ -157,7 +158,7 @@ librdf_node *Soprano::Redland::World::createNode( const Node& node )
         return librdf_new_node_from_typed_literal( world,
                                                    (unsigned char *)node.literal().toString().toUtf8().data(),
                                                    node.language().toUtf8().data(),
-                                                   node.language().isEmpty() // redland does only handle non-empty lang values for rdfs:Literal
+                                                   !node.literal().isPlain()
                                                    ? librdf_new_uri( world, (const unsigned char*)node.dataType().toEncoded().data() )
                                                    : 0 );
     }
@@ -192,13 +193,14 @@ Soprano::Node Soprano::Redland::World::createNode( librdf_node *node )
     else if ( librdf_node_is_literal( node ) ) {
         librdf_uri* datatype = librdf_node_get_literal_value_datatype_uri( node );
         if ( !datatype ) {
-            return Soprano::Node( Soprano::LiteralValue( QString::fromUtf8( (const char *)librdf_node_get_literal_value( node ) ) ),
-                                  QString::fromAscii( librdf_node_get_literal_value_language( node ) ) );
+            return Soprano::Node( Soprano::LiteralValue::createPlainLiteral( QString::fromUtf8( (const char *)librdf_node_get_literal_value( node ) ),
+                                                                             QString::fromAscii( librdf_node_get_literal_value_language( node ) ) ) );
+        }
+        else {
+            return Soprano::Node( Soprano::LiteralValue::fromString( QString::fromUtf8( (const char *)librdf_node_get_literal_value( node ) ),
+                                                                     QUrl::fromEncoded( (const char *)librdf_uri_as_string( datatype ),
+                                                                                        QUrl::StrictMode ) ) );
         }
-        return Soprano::Node( Soprano::LiteralValue::fromString( QString::fromUtf8( (const char *)librdf_node_get_literal_value( node ) ),
-                                                                 QUrl::fromEncoded( (const char *)librdf_uri_as_string( datatype ),
-                                                                                    QUrl::StrictMode ) ),
-                              QString::fromAscii( librdf_node_get_literal_value_language( node ) ) );
     }
 
     return Soprano::Node();
@@ -228,3 +230,9 @@ void Soprano::Redland::World::freeStatement( librdf_statement* statement )
         librdf_free_statement( statement );
     }
 }
+
+
+Soprano::Redland::World* Soprano::Redland::World::theWorld()
+{
+    return s_theWorld();
+}
