@@ -132,11 +132,15 @@ bool Soprano::VirtuosoController::start( const BackendSettings& settings, RunFla
 
         QStringList args;
         args << "+foreground"
-             << "+configfile" << QDir::toNativeSeparators(m_configFilePath)
-             << "+wait";
-
+             << "+configfile" << QDir::toNativeSeparators(m_configFilePath);
+#ifndef Q_OS_WIN
+        args << "+wait";
+#endif
         qDebug() << "Starting Virtuoso server:" << virtuosoExe << args;
 
+        // We need to set the working directory cause virtuoso creates a temp checkpoint_in_progress file
+        // in the directory it was started.
+        m_virtuosoProcess.setWorkingDirectory( storageDir );
         m_virtuosoProcess.start( virtuosoExe, args, QIODevice::ReadOnly );
         m_virtuosoProcess.setReadChannel( QProcess::StandardError );
         m_virtuosoProcess.closeReadChannel( QProcess::StandardOutput );
@@ -273,7 +277,7 @@ void Soprano::VirtuosoController::writeConfigFile( const QString& path, const Ba
 
     // backwards compatibility
     int numberOfBuffers = valueInSettings( settings, "buffers", 2000 ).toInt();
-    int numberOfThreads = valueInSettings( settings, "threads", 10 ).toInt();
+    int numberOfThreads = valueInSettings( settings, "threads", 100 ).toInt();
 
     numberOfBuffers = valueInSettings( settings, "NumberOfBuffers", numberOfBuffers ).toInt();
     numberOfThreads = valueInSettings( settings, "ServerThreads", numberOfThreads ).toInt();
