@@ -116,8 +116,7 @@ Soprano::VirtuosoModel::VirtuosoModel( ODBC::ConnectionPool* connectionPool, con
 
 Soprano::VirtuosoModel::~VirtuosoModel()
 {
-    while ( !d->m_openIterators.isEmpty() )
-        d->m_openIterators.last()->close();
+    d->closeAllIterators();
     delete d->connectionPool;
     delete d;
 }
@@ -421,9 +420,7 @@ Soprano::QueryResultIterator Soprano::VirtuosoModel::executeQuery( const QString
         ODBC::QueryResult* result = conn->executeQuery( finalQuery );
         if ( result ) {
             clearError();
-            Virtuoso::QueryResultIteratorBackend* backend = new Virtuoso::QueryResultIteratorBackend( result );
-            backend->d->m_model = d;
-            d->addIterator( backend );
+            Virtuoso::QueryResultIteratorBackend* backend = new Virtuoso::QueryResultIteratorBackend( d, result );
             return backend;
         }
         else {
