@@ -1,7 +1,7 @@
 /*
  * This file is part of Soprano Project
  *
- * Copyright (C) 2008 Sebastian Trueg <trueg@kde.org>
+ * Copyright (C) 2008-2010 Sebastian Trueg <trueg@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -42,10 +42,13 @@
 #include <QtCore/QDebug>
 
 
-Soprano::Virtuoso::QueryResultIteratorBackend::QueryResultIteratorBackend( ODBC::QueryResult* result )
+Soprano::Virtuoso::QueryResultIteratorBackend::QueryResultIteratorBackend( VirtuosoModelPrivate* model, ODBC::QueryResult* result )
     : Soprano::QueryResultIteratorBackend(),
       d( new QueryResultIteratorBackendPrivate() )
 {
+    d->m_model = model;
+    d->m_model->addIterator( this );
+
     // cache binding names
     d->m_queryResult = result;
     d->m_resultType = QueryResultIteratorBackendPrivate::UnknownResult;
@@ -253,12 +256,17 @@ void Soprano::Virtuoso::QueryResultIteratorBackend::close()
     // which may happen in a different thread indeed.
     //
     d->m_closeMutex.lock();
-    if ( d->m_model ) {
-        d->m_model->removeIterator( this );
-        d->m_model = 0;
-        d->graphIterator.close();
-        delete d->m_queryResult;
-        d->m_queryResult = 0;
-    }
+
+    VirtuosoModelPrivate* model = d->m_model;
+    d->m_model = 0;
+
+    d->graphIterator.close();
+    delete d->m_queryResult;
+    d->m_queryResult = 0;
+
     d->m_closeMutex.unlock();
+
+    if ( model ) {
+        model->removeIterator(this);
+    }
 }
